commit 49ec848465f7ece421c646b2be32411fd39fb2ca
Author: Shérab <Sebastien.Hinderer@ens-lyon.org>
Date:   Tue May 8 15:52:17 2018 +0200

    Slightly enhance braille navigation
    
    Make it possible to move one window left (resp. right) with the
    CMD_FINLTSKIP (resp. CMD_FWINRTSKIP) brltty commands.

diff --git a/src/orca/braille.py b/src/orca/braille.py
index 716f8259d..88a6cf6c3 100644
--- a/src/orca/braille.py
+++ b/src/orca/braille.py
@@ -107,6 +107,7 @@ _monitor = None
 dontInteruptSpeechKeys = []
 if _brlAPIAvailable:
     dontInteruptSpeechKeys = [brlapi.KEY_CMD_FWINLT, brlapi.KEY_CMD_FWINRT, \
+        brlapi.KEY_CMD_FWINLTSKIP, brlapi.KEY_CMD_FWINRTSKIP, \
         brlapi.KEY_CMD_LNUP, brlapi.KEY_CMD_LNDN]
 
 # Common names for most used BrlTTY commands, to be shown in the GUI:
@@ -115,18 +116,20 @@ if _brlAPIAvailable:
 command_name = {}
 
 if _brlAPIAvailable:
-    command_name[brlapi.KEY_CMD_FWINLT]   = cmdnames.BRAILLE_LINE_LEFT
-    command_name[brlapi.KEY_CMD_FWINRT]   = cmdnames.BRAILLE_LINE_RIGHT
-    command_name[brlapi.KEY_CMD_LNUP]     = cmdnames.BRAILLE_LINE_UP
-    command_name[brlapi.KEY_CMD_LNDN]     = cmdnames.BRAILLE_LINE_DOWN
-    command_name[brlapi.KEY_CMD_FREEZE]   = cmdnames.BRAILLE_FREEZE
-    command_name[brlapi.KEY_CMD_TOP_LEFT] = cmdnames.BRAILLE_TOP_LEFT
-    command_name[brlapi.KEY_CMD_BOT_LEFT] = cmdnames.BRAILLE_BOTTOM_LEFT
-    command_name[brlapi.KEY_CMD_HOME]     = cmdnames.BRAILLE_HOME
-    command_name[brlapi.KEY_CMD_SIXDOTS]  = cmdnames.BRAILLE_SIX_DOTS
-    command_name[brlapi.KEY_CMD_ROUTE]    = cmdnames.BRAILLE_ROUTE_CURSOR
-    command_name[brlapi.KEY_CMD_CUTBEGIN] = cmdnames.BRAILLE_CUT_BEGIN
-    command_name[brlapi.KEY_CMD_CUTLINE]  = cmdnames.BRAILLE_CUT_LINE
+    command_name[brlapi.KEY_CMD_FWINLT]     = cmdnames.BRAILLE_LINE_LEFT
+    command_name[brlapi.KEY_CMD_FWINLTSKIP] = cmdnames.BRAILLE_LINE_LEFT
+    command_name[brlapi.KEY_CMD_FWINRT]     = cmdnames.BRAILLE_LINE_RIGHT
+    command_name[brlapi.KEY_CMD_FWINRTSKIP] = cmdnames.BRAILLE_LINE_RIGHT
+    command_name[brlapi.KEY_CMD_LNUP]       = cmdnames.BRAILLE_LINE_UP
+    command_name[brlapi.KEY_CMD_LNDN]       = cmdnames.BRAILLE_LINE_DOWN
+    command_name[brlapi.KEY_CMD_FREEZE]     = cmdnames.BRAILLE_FREEZE
+    command_name[brlapi.KEY_CMD_TOP_LEFT]   = cmdnames.BRAILLE_TOP_LEFT
+    command_name[brlapi.KEY_CMD_BOT_LEFT]   = cmdnames.BRAILLE_BOTTOM_LEFT
+    command_name[brlapi.KEY_CMD_HOME]       = cmdnames.BRAILLE_HOME
+    command_name[brlapi.KEY_CMD_SIXDOTS]    = cmdnames.BRAILLE_SIX_DOTS
+    command_name[brlapi.KEY_CMD_ROUTE]      = cmdnames.BRAILLE_ROUTE_CURSOR
+    command_name[brlapi.KEY_CMD_CUTBEGIN]   = cmdnames.BRAILLE_CUT_BEGIN
+    command_name[brlapi.KEY_CMD_CUTLINE]    = cmdnames.BRAILLE_CUT_LINE
 
 # The size of the physical display (width, height).  The coordinate system of
 # the display is set such that the upper left is (0,0), x values increase from
diff --git a/src/orca/scripts/default.py b/src/orca/scripts/default.py
index e6f949ac9..6b025ccd2 100644
--- a/src/orca/scripts/default.py
+++ b/src/orca/scripts/default.py
@@ -676,29 +676,33 @@ class Script(script.Script):
         """
         brailleBindings = script.Script.getBrailleBindings(self)
         try:
-            brailleBindings[braille.brlapi.KEY_CMD_FWINLT]   = \
+            brailleBindings[braille.brlapi.KEY_CMD_FWINLT]     = \
                 self.inputEventHandlers["panBrailleLeftHandler"]
-            brailleBindings[braille.brlapi.KEY_CMD_FWINRT]   = \
+            brailleBindings[braille.brlapi.KEY_CMD_FWINLTSKIP] = \
+                self.inputEventHandlers["panBrailleLeftHandler"]
+            brailleBindings[braille.brlapi.KEY_CMD_FWINRT]     = \
+                self.inputEventHandlers["panBrailleRightHandler"]
+            brailleBindings[braille.brlapi.KEY_CMD_FWINRTSKIP] = \
                 self.inputEventHandlers["panBrailleRightHandler"]
-            brailleBindings[braille.brlapi.KEY_CMD_LNUP]     = \
+            brailleBindings[braille.brlapi.KEY_CMD_LNUP]       = \
                 self.inputEventHandlers["reviewAboveHandler"]
-            brailleBindings[braille.brlapi.KEY_CMD_LNDN]     = \
+            brailleBindings[braille.brlapi.KEY_CMD_LNDN]       = \
                 self.inputEventHandlers["reviewBelowHandler"]
-            brailleBindings[braille.brlapi.KEY_CMD_FREEZE]   = \
+            brailleBindings[braille.brlapi.KEY_CMD_FREEZE]     = \
                 self.inputEventHandlers["toggleFlatReviewModeHandler"]
-            brailleBindings[braille.brlapi.KEY_CMD_TOP_LEFT] = \
+            brailleBindings[braille.brlapi.KEY_CMD_TOP_LEFT]   = \
                 self.inputEventHandlers["reviewHomeHandler"]
-            brailleBindings[braille.brlapi.KEY_CMD_BOT_LEFT] = \
+            brailleBindings[braille.brlapi.KEY_CMD_BOT_LEFT]   = \
                 self.inputEventHandlers["reviewBottomLeftHandler"]
-            brailleBindings[braille.brlapi.KEY_CMD_HOME]     = \
+            brailleBindings[braille.brlapi.KEY_CMD_HOME]       = \
                 self.inputEventHandlers["goBrailleHomeHandler"]
-            brailleBindings[braille.brlapi.KEY_CMD_SIXDOTS]   = \
+            brailleBindings[braille.brlapi.KEY_CMD_SIXDOTS]     = \
                 self.inputEventHandlers["contractedBrailleHandler"]
-            brailleBindings[braille.brlapi.KEY_CMD_ROUTE]   = \
+            brailleBindings[braille.brlapi.KEY_CMD_ROUTE]     = \
                 self.inputEventHandlers["processRoutingKeyHandler"]
-            brailleBindings[braille.brlapi.KEY_CMD_CUTBEGIN] = \
+            brailleBindings[braille.brlapi.KEY_CMD_CUTBEGIN]   = \
                 self.inputEventHandlers["processBrailleCutBeginHandler"]
-            brailleBindings[braille.brlapi.KEY_CMD_CUTLINE] = \
+            brailleBindings[braille.brlapi.KEY_CMD_CUTLINE]   = \
                 self.inputEventHandlers["processBrailleCutLineHandler"]
         except AttributeError:
             msg = 'DEFAULT: Braille bindings unavailable in %s' % self
